summaryrefslogtreecommitdiff
path: root/innobase/include/sync0sync.h
diff options
context:
space:
mode:
Diffstat (limited to 'innobase/include/sync0sync.h')
-rw-r--r--innobase/include/sync0sync.h6
1 files changed, 2 insertions, 4 deletions
diff --git a/innobase/include/sync0sync.h b/innobase/include/sync0sync.h
index 3acf3415889..3348da2851c 100644
--- a/innobase/include/sync0sync.h
+++ b/innobase/include/sync0sync.h
@@ -119,16 +119,14 @@ Prints wait info of the sync system. */
void
sync_print_wait_info(
/*=================*/
- char* buf, /* in/out: buffer where to print */
- char* buf_end); /* in: buffer end */
+ FILE* file); /* in: file where to print */
/***********************************************************************
Prints info of the sync system. */
void
sync_print(
/*=======*/
- char* buf, /* in/out: buffer where to print */
- char* buf_end); /* in: buffer end */
+ FILE* file); /* in: file where to print */
/**********************************************************************
Checks that the mutex has been initialized. */